summaryrefslogtreecommitdiffstats
path: root/lib/kross/api/callable.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-16 09:56:31 -0600
committerTimothy Pearson <[email protected]>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /lib/kross/api/callable.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'lib/kross/api/callable.h')
-rw-r--r--lib/kross/api/callable.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kross/api/callable.h b/lib/kross/api/callable.h
index 0e3dd3a6..63edb067 100644
--- a/lib/kross/api/callable.h
+++ b/lib/kross/api/callable.h
@@ -92,9 +92,9 @@ namespace Kross { namespace Api {
Object::Ptr getChild(const TQString& name) const;
/**
- * Return all children.
+ * Return all tqchildren.
*
* \return A \a ObjectMap of children this Object has.
*/
TQMap<TQString, Object::Ptr> getChildren() const;
@@ -125,7 +125,7 @@ namespace Kross { namespace Api {
void removeChild(const TQString& name);
/**
* Remove all children.
*/
void removeAllChildren();
@@ -138,7 +138,7 @@ namespace Kross { namespace Api {
/// Name this callable object has.
TQString m_name;
/// A list of childobjects.
- TQMap<TQString, Object::Ptr> m_children;
+ TQMap<TQString, Object::Ptr> m_tqchildren;
};
}}
@@ -92,9 +92,9 @@ namespace Kross { namespace Api {
*
- * \return A \a ObjectMap of children this Object has.
+ * \return A \a ObjectMap of tqchildren this Object has.
*/
TQMap<TQString, Object::Ptr> getChildren() const;
@@ -125,7 +125,7 @@ namespace Kross { namespace Api {
void removeChild(const TQString& name);
/**
- * Remove all children.
+ * Remove all tqchildren.
*/
void removeAllChildren();